from fastmcp import FastMCP
from fastmcp.server.middleware.error_handling import ErrorHandlingMiddleware
from fastmcp.utilities.types import Image
from mcp.types import Icon

from src.config import settings
from src.middleware import FinamCredentialsMiddleware
from src.servers.account import account_mcp
from src.servers.assets import assets_mcp
from src.servers.market_data import market_data_mcp
from src.servers.order import order_mcp

img = Image(path=settings.PROJECT_PATH / "assets/logo.svg")
icon = Icon(src=img.to_data_uri())

finam_mcp = FastMCP("FinamMCP", icons=[icon])

finam_mcp.mount(account_mcp, namespace="account")
finam_mcp.mount(market_data_mcp, namespace="market_data")
finam_mcp.mount(assets_mcp, namespace="assets")
finam_mcp.mount(order_mcp, namespace="order")

if settings.INCLUDE_SERVERS:
    finam_mcp.enable(tags=settings.INCLUDE_SERVERS, only=True)

finam_mcp.add_middleware(FinamCredentialsMiddleware())
finam_mcp.add_middleware(ErrorHandlingMiddleware())

if __name__ == "__main__":
    finam_mcp.run(transport="http", host="127.0.0.1", port=3000)



from src.tradeapi.finam_client import FinamClient


async def create_finam_client(api_key: str, account_id: str) -> FinamClient:
    """Создать FinamClient с проверкой токена"""
    client = await FinamClient.create(api_key=api_key, account_id=account_id)
    # Проверка токена
    details = await client.get_jwt_token_details()
    if account_id not in details.account_ids:
        raise RuntimeError(f"Account ID {account_id} not found.")
    return client



from fastmcp.server.dependencies import get_context

from src.tradeapi.finam_client import FinamClient


async def get_finam_client() -> FinamClient:
    return await get_context().get_state("finam_client")
